{% extends "admin/index.html" %}

{% block sidebar %}
  {{ block.super }}

  {% if custom_list %}
  <div class="module" style="float: left; width: 498px">
    <table style="width: 100%">
      <caption>Djrill</caption>
      <tbody>
        {% for path, name in custom_list %}
          <tr><td><a href="{{ path }}">{{ name|capfirst }}</a></td></tr>
        {% endfor %}
      </tbody>
    </table>
  </div>
  {% endif %}
{% endblock %}
